Struct google_cloudtrace1::ListTracesResponse [−][src]
pub struct ListTracesResponse {
pub next_page_token: Option<String>,
pub traces: Option<Vec<Trace>>,
}The response message for the ListTraces method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- traces list projects (response)
Fields
next_page_token: Option<String>
If defined, indicates that there are more traces that match the request and that this value should be passed to the next request to continue retrieving additional traces.
traces: Option<Vec<Trace>>
List of trace records as specified by the view parameter.